@@ -4,11 +4,19 @@ from rest_framework.exceptions import ParseError
 from django.http import QueryDict
 from django.conf import settings
 
+DRF_OPTIONS = {
+    "querydict": True
+}
 
 class NestedParser(NestPars):
 
     def __init__(self, data):
-        super().__init__(data, getattr(settings, "DRF_NESTED_MULTIPART_PARSER", {}))
+        # merge django settings to default DRF_OPTIONS ( special parser options in on parser)
+        options = {
+            **DRF_OPTIONS,
+            **getattr(settings, "DRF_NESTED_MULTIPART_PARSER", {})
+        }
+        super().__init__(data, options)
 
     def convert_value(self, data, key):
         # all value in querydict as set in list
@@ -19,12 +27,17 @@ class NestedParser(NestPars):
 
     @property
     def validate_data(self):
+        data = super().validate_data
+        
+        # return dict ( not conver to querydict)
+        if not self._options["querydict"]:
+            return data
+        
         dtc = QueryDict(mutable=True)
-        dtc.update(super().validate_data)
+        dtc.update(data)
         dtc.mutable = False
         return dtc
 
-
 class DrfNestedParser(MultiPartParser):
 
     def parse(self, stream, media_type=None, parser_context=None):
